@@ -18,6 +18,7 @@
 #include <KStandardGuiItem>
 
 #include "queuemanagermodel.h"
+#include <qframe.h>
 #include <torrent/queuemanager.h>
 #include <util/log.h>
 
@@ -29,12 +30,12 @@ QueueManagerWidget::QueueManagerWidget(QueueManager *qman, QWidget *parent)
     : QWidget(parent)
     , qman(qman)
 {
-    QHBoxLayout *layout = new QHBoxLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
-    layout->setSpacing(0);
+    auto mainLayout = new QVBoxLayout(this);
+    mainLayout->setContentsMargins(0, 0, 0, 0);
+    mainLayout->setSpacing(0);
+    QHBoxLayout *layout = new QHBoxLayout();
+    mainLayout->addLayout(layout);
     QVBoxLayout *vbox = new QVBoxLayout();
-    vbox->setContentsMargins(0, 0, 0, 0);
-    vbox->setSpacing(0);
     view = new QTreeView(this);
     view->setUniformRowHeights(true);
     toolbar = new QToolBar(this);
@@ -42,6 +43,11 @@ QueueManagerWidget::QueueManagerWidget(QueueManager *qman, QWidget *parent)
     toolbar->setToolButtonStyle(Qt::ToolButtonIconOnly);
     layout->addWidget(toolbar);
 
+    auto separator = new QFrame(this);
+    separator->setFrameShape(QFrame::HLine);
+    separator->setFixedHeight(1);
+    mainLayout->addWidget(separator);
+
     search = new QLineEdit(this);
     search->setPlaceholderText(i18n("Search"));
     search->setClearButtonEnabled(true);
@@ -96,6 +102,7 @@ QueueManagerWidget::QueueManagerWidget(QueueManager *qman, QWidget *parent)
     view->setDropIndicatorShown(true);
     view->setAutoScroll(true);
     view->setSelectionMode(QAbstractItemView::ContiguousSelection);
+    view->setProperty("_breeze_borders_sides", QVariant::fromValue(QFlags<Qt::Edge>{Qt::LeftEdge}));
 
     connect(view->selectionModel(), &QItemSelectionModel::selectionChanged, this, &QueueManagerWidget::selectionChanged);
 
@@ -210,7 +217,7 @@ void QueueManagerWidget::moveBottomClicked()
 
 void QueueManagerWidget::saveState(KSharedConfigPtr cfg)
 {
-    KConfigGroup g = cfg->group("QueueManagerWidget");
+    KConfigGroup g = cfg->group(QStringLiteral("QueueManagerWidget"));
     QByteArray s = view->header()->saveState();
     g.writeEntry("view_state", s.toBase64());
     g.writeEntry("search_text", search->text());
@@ -222,7 +229,7 @@ void QueueManagerWidget::saveState(KSharedConfigPtr cfg)
 
 void QueueManagerWidget::loadState(KSharedConfigPtr cfg)
 {
-    KConfigGroup g = cfg->group("QueueManagerWidget");
+    KConfigGroup g = cfg->group(QStringLiteral("QueueManagerWidget"));
     QByteArray s = QByteArray::fromBase64(g.readEntry("view_state", QByteArray()));
     if (!s.isEmpty())
         view->header()->restoreState(s);
