@@ -21,7 +21,9 @@ JobProgressWidget::~JobProgressWidget()
 
 void JobProgressWidget::emitCloseRequest()
 {
-    closeRequest(this);
+    Q_EMIT closeRequest(this);
 }
 
 }
+
+#include "moc_jobprogresswidget.cpp"
