@@ -242,12 +242,11 @@ void TorrentFileTreeModel::Node::loadExpandedState(const QModelIndex &index,
                                                    TorrentFileTreeModel *real_model,
                                                    QSortFilterProxyModel *pm,
                                                    QTreeView *tv,
-                                                   BNode *n) const
+                                                   BDictNode *dict) const
 {
     if (file)
         return;
 
-    BDictNode *dict = dynamic_cast<BDictNode *>(n);
     if (!dict)
         return;
 
@@ -644,7 +643,7 @@ QByteArray TorrentFileTreeModel::saveExpandedState(QSortFilterProxyModel *pm, QT
         return QByteArray();
 
     QByteArray data;
-    BEncoder enc(new BEncoderBufferOutput(data));
+    BEncoder enc(std::make_unique<BEncoderBufferOutput>(data));
     enc.beginDict();
     root->saveExpandedState(index(0, 0, QModelIndex()), this, pm, tv, &enc);
     enc.end();
@@ -657,16 +656,14 @@ void TorrentFileTreeModel::loadExpandedState(QSortFilterProxyModel *pm, QTreeVie
         return;
 
     BDecoder dec(state, false, 0);
-    BNode *n = nullptr;
     try {
-        n = dec.decode();
-        if (n && n->getType() == BNode::DICT) {
-            root->loadExpandedState(index(0, 0, QModelIndex()), this, pm, tv, n);
+        const std::unique_ptr<BDictNode> dict = dec.decodeDict();
+        if (dict) {
+            root->loadExpandedState(index(0, 0, QModelIndex()), this, pm, tv, dict.get());
         }
     } catch (bt::Error &err) {
         Out(SYS_GEN | LOG_DEBUG) << "Failed to load expanded state" << endl;
     }
-    delete n;
 }
 
 bt::TorrentFileInterface *TorrentFileTreeModel::indexToFile(const QModelIndex &idx)
