@@ -1,22 +1,7 @@
-/***************************************************************************
- *   Copyright (C) 2009 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef KT_SHUTDOWNRULESET_H
 #define KT_SHUTDOWNRULESET_H
@@ -102,7 +87,7 @@ public:
     /**
         Add a rule to the ruleset
     */
-    void addRule(Action action, Target target, Trigger trigger, bt::TorrentInterface *tc = 0);
+    void addRule(Action action, Target target, Trigger trigger, bt::TorrentInterface *tc = nullptr);
 
     /**
         Clear all rules
