@@ -1,17 +1,6 @@
 /*
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-FileCopyrightText: 2009 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KT_SHUTDOWNTORRENTMODEL_H
@@ -36,7 +25,7 @@ class ShutdownTorrentDelegate : public QStyledItemDelegate
 {
     Q_OBJECT
 public:
-    ShutdownTorrentDelegate(QObject *parent = 0);
+    ShutdownTorrentDelegate(QObject *parent = nullptr);
     ~ShutdownTorrentDelegate() override;
 
     QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
